from dapiclient.client import DAPIClient
import cbor2

client = DAPIClient()


def getDocuments(data):
    docs = client.getDocuments(
        data['contract_id'],
        data['document_type'],
        data['where'],
        limit=2, # Only one document
    )

    documents = []
    
    for  doc in docs:
        documents.append(cbor2.loads(doc))
    
    return documents[0] # Return the only document in the list







def verifyURLField(doc, field):
    ''' Checks whether the url is in the right field'''
    print("Thumbor DASH STATUS: Verifying url field........" )
    if doc['field'] == field :
        return True
        print("Thumbor DASH STATUS: Successfully verified url field........" )
    else:
        print("Thumbor DASH STATUS: Error verifying url field........" )
        return False


"""Encrypted URLs for thumbor encryption."""

import base64

from libthumbor.crypto import CryptoURL
from six import PY3, b, text_type
from thumbor_dash.url import plain_image_url, unsafe_url

class ThumborDashCryptoURL(CryptoURL):
     """Class responsible for generating encrypted URLs for thumbor"""

     def generate_new(self, options):
        url = plain_image_url(**options)
        _hmac = self.hmac.copy()
        _hmac.update(text_type(url).encode("utf-8"))
        signature = base64.urlsafe_b64encode(_hmac.digest())

        if PY3:
            signature = signature.decode("ascii")
        return "/%s/%s" % (signature, url)

     def generate(self, **options):
         """Generates an encrypted URL with the specified options"""
         if options.get("unsafe", False):
             return unsafe_url(**options)
         return self.generate_new(options)


import sys
from thumbor_dash.app import ThumborDashServiceApp

import tornado.ioloop

from thumbor.console import get_server_parameters
from thumbor.signal_handler import setup_signal_handler
from thumbor.server import run_server, get_importer, get_config, configure_log, validate_config, get_context, get_as_integer

def get_application(context):
    return ThumborDashServiceApp(context)

def main(arguments=None):
    """Runs thumbor server with the specified arguments."""
    if arguments is None:
        arguments = sys.argv[1:]

    server_parameters = get_server_parameters(arguments)
    config = get_config(
        server_parameters.config_path, server_parameters.use_environment
    )
    configure_log(config, server_parameters.log_level.upper())

    validate_config(config, server_parameters)

    importer = get_importer(config)

    with get_context(server_parameters, config, importer) as context:
        application = get_application(context)
        server = run_server(application, context)
        setup_signal_handler(server, config)
        tornado.ioloop.IOLoop.instance().start()


if __name__ == "__main__":
    main(sys.argv[1:])